@@ -50,7 +50,7 @@ ex_data_table.relop_project <- function(optree,
     stop("rqdatatable::ex_data_table.relop_project() must have at least one grouping term")
   }
   tmpnam <- ".rquery_ex_extend_tmp"
-  tmpenv <- new.env(parent = env)
+  tmpenv <- new.env(parent = globalenv())
   assign(tmpnam, x, envir = tmpenv)
   enames <-
     vapply(seq_len(n),
@@ -68,6 +68,6 @@ ex_data_table.relop_project <- function(optree,
                 byi,
                 " ]")
   expr <- parse(text = src)
-  eval(expr, envir = tmpenv, enclos = env)
+  eval(expr, envir = tmpenv, enclos = tmpenv)
 }
 
